**To delete a configuration profile**

The following ``delete-configuration-profile`` example deletes the specified configuration profile. ::

    aws appconfig delete-configuration-profile \
        --application-id 339ohji \
        --configuration-profile-id ur8hx2f

This command produces no output.

For more information, see `Step 3: Creating a configuration and a configuration profile <https://docs.aws.amazon.com/appconfig/latest/userguide/appconfig-creating-configuration-and-profile.html>`__ in the *AWS AppConfig User Guide*.